Struct ZwlrVirtualPointerManagerV1
pub struct ZwlrVirtualPointerManagerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
virtual pointer manager
This object allows clients to create individual virtual pointer objects.
This interface has no events.
Implementations
impl ZwlrVirtualPointerManagerV1
impl ZwlrVirtualPointerManagerV1
pub fn create_virtual_pointer<U, D>(
&self,
seat: Option<&WlSeat>,
qh: &QueueHandle<D>,
udata: U,
) -> ZwlrVirtualPointerV1
pub fn create_virtual_pointer<U, D>( &self, seat: Option<&WlSeat>, qh: &QueueHandle<D>, udata: U, ) -> ZwlrVirtualPointerV1
Create a new virtual pointer
Creates a new virtual pointer. The optional seat is a suggestion to the compositor.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the virtual pointer manager
pub fn create_virtual_pointer_with_output<U, D>(
&self,
seat: Option<&WlSeat>,
output: Option<&WlOutput>,
qh: &QueueHandle<D>,
udata: U,
) -> ZwlrVirtualPointerV1
pub fn create_virtual_pointer_with_output<U, D>( &self, seat: Option<&WlSeat>, output: Option<&WlOutput>, qh: &QueueHandle<D>, udata: U, ) -> ZwlrVirtualPointerV1
Create a new virtual pointer
Creates a new virtual pointer. The seat and the output arguments are optional. If the seat argument is set, the compositor should assign the input device to the requested seat. If the output argument is set, the compositor should map the input device to the requested output.